Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(401)

Unified Diff: media/renderers/video_renderer_impl.h

Issue 2075293003: CL for perf tryjob on mac (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/renderers/audio_renderer_impl.cc ('k') | media/renderers/video_renderer_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/renderers/video_renderer_impl.h
diff --git a/media/renderers/video_renderer_impl.h b/media/renderers/video_renderer_impl.h
index 24726b3018b8416efa5073ad9a9995f0871dc2e9..2307b634d5301b5af74a63dc22cc6132aab2cec0 100644
--- a/media/renderers/video_renderer_impl.h
+++ b/media/renderers/video_renderer_impl.h
@@ -96,6 +96,9 @@ class MEDIA_EXPORT VideoRendererImpl
void OnBufferingStateChange(BufferingState state);
void OnWaitingForDecryptionKey();
+ // Callback for |video_frame_stream_| to report statistics.
+ void BytesDecoded(uint64_t bytes);
+
// Callback for |video_frame_stream_| to deliver decoded video frames and
// report video decoding status. If a frame is available the planes will be
// copied asynchronously and FrameReady will be called once finished copying.
@@ -253,8 +256,9 @@ class MEDIA_EXPORT VideoRendererImpl
base::TimeDelta start_timestamp_;
// Keeps track of the number of frames decoded and dropped since the
// last call to |statistics_cb_|. These must be accessed under lock.
+ uint64_t bytes_decoded_;
int frames_decoded_;
int frames_dropped_;
« no previous file with comments | « media/renderers/audio_renderer_impl.cc ('k') | media/renderers/video_renderer_impl.cc » ('j') | no next file with comments »
@@ -253,8 +256,9 @@ class MEDIA_EXPORT VideoRendererImpl
base::TimeDelta start_timestamp_;
- // Keeps track of the number of frames decoded and dropped since the
+ // Keeps track of the number of bytes/frames decoded and dropped since the
// last call to |statistics_cb_|. These must be accessed under lock.

Powered by Google App Engine
This is Rietveld 408576698